@@ -2,7 +2,6 @@ from __future__ import unicode_literals
 
 import json
 
-from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.test import TestCase, RequestFactory
 from django.views.generic import View
@@ -14,10 +13,12 @@ from ..oauth2_validators import OAuth2Validator
 from ..settings import oauth2_settings
 from ..views import ProtectedResourceView
 from ..views.mixins import OAuthLibMixin
+from ..compat import get_user_model
 from .test_utils import TestCaseUtils
 
 
 Application = get_application_model()
+UserModel = get_user_model()
 
 
 # mocking a protected resource view
@@ -29,8 +30,8 @@ class ResourceView(ProtectedResourceView):
 class BaseTest(TestCaseUtils, TestCase):
     def setUp(self):
         self.factory = RequestFactory()
-        self.test_user = User.objects.create_user("test_user", "test@user.com", "123456")
-        self.dev_user = User.objects.create_user("dev_user", "dev@user.com", "123456")
+        self.test_user = UserModel.objects.create_user("test_user", "test@user.com", "123456")
+        self.dev_user = UserModel.objects.create_user("dev_user", "dev@user.com", "123456")
 
         self.application = Application(
             name="test_client_credentials_app",
