@@ -1,18 +1,19 @@
 from __future__ import unicode_literals
 
 from django.test import TestCase
-from django.contrib.auth.models import User
 from django.core.exceptions import ValidationError
 
 from ..models import AccessToken, get_application_model
+from ..compat import get_user_model
 
 
 Application = get_application_model()
+UserModel = get_user_model()
 
 
 class TestModels(TestCase):
     def setUp(self):
-        self.user = User.objects.create_user("test_user", "test@user.com", "123456")
+        self.user = UserModel.objects.create_user("test_user", "test@user.com", "123456")
 
     def test_allow_scopes(self):
         self.client.login(username="test_user", password="123456")
